==> GeneSpring_1.0.1.tar.gz: GeneSpring/man/GSint2BC.Rd <==
\name{GSint2BC}
\alias{GSint2BC}
\alias{BC2GSint}
\title{ Convertors for GeneSpring GSint and Bioconductor exprSet objects }

\description{
These functions convert GeneSpring Experiment (Interpretation) objects
into BioConductor expression objects and vice versa.
}

\usage{
expr.set <- GSint2BC(interpretation, what = "nor")
gs.int <- BC2GSint(exprSet)
}

\arguments{
  \item{interpretation}{ GeneSpring Expereiment Interpretation object }
  \item{what}{ For \code{GSload.intBC()} only. Indicates what data from the
   GeneSpring Experiment Interpretation should be used.
   Valid values for \code{what} can be \code{nor} and \code{raw}, representing
   Normalized or Raw expression values. The Control values cannot be used.}
  \item{exprSet}{ GeneSpring Expereiment Interpretation object }
}

\details{
The GeneSpring Experiment Interpretation and the BioConductor objects are
quite similar, but there are some differences. GeneSpring interpretations
can contain information on both normalized and original raw values, and
can include, Standard Error, Standard Deviation and number of replicates
information, but the BioConductor objects can contain more sample attribute
information in the form of the MIAME annotations.

These functions provide convertors for both types of objects.

When converting a GeneSpring object into a BioConductor object, the user
has the choice of either using the normalized or raw expression values for
the BioConductor exprSet object. Conversely, when a BioConductor objects is
converted into a GeneSpring object, the expression values are loaded as
normalized values.

The phenoData objects describing the phenotypical data for the samples in a
BioConductor object are converted into Experimental Parameter objects in the
GeneSpring class object, and vice versa.

The experiment name and any of the other annotations for the BioConductor
objects that are stored in the MIAME objects are currently not converted,
although future versions of these convertors may provide better mapping.
}

\value{
The return value depends on which fucntion was called.
The \code{BC2GSint()} function returns an object of class \code{GSint}.
The \code{GSint2BC()} function returns a BioConductor object of class \code{exprSet}.
See the documentation on \code{GSint} and \code{exprSet} for more information.
}

\references{ 

For more information on using GeneSpring with R see
\url{http://www.silicongenetics.com/cgi/SiG.cgi/Support/GeneSpring/GSnotes/R.smf}
}
\author{ 
   Thon de Boer, Silicon Genetics, Redwood city, CA, USA \email{thon@silicongenetics.com}

}
\note{ This and any other functions in the GeneSpring package are only useful,
when using Silicon Genetics Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.exp}},
\code{\link{GSload.int}},
\code{\link{GSsave.exp}}
}
\examples{
#Use the example data etc. from exprSet
library(Biobase)
data(geneData)
data(geneCov)
covdesc<- list("Covariate 1", "Covariate 2", "Covariate 3")
names(covdesc) <- names(geneCov)
pdata <- new("phenoData", pData=geneCov, varLabels=covdesc)
eset <- new("exprSet", exprs=geneData, phenoData=pdata)

#Convert the objects into GeneSpring objects and back again
gs.int <- BC2GSint(eset)
expr.set <- GSint2BC(gs.int)

}
\keyword{ IO }% at least one, from doc/KEYWORDS

==> GeneSpring_2.4.0.tar.gz: GeneSpring/man/GSint2BC.Rd <==
\name{GSint2BC}
\alias{GSint2BC}
\alias{BC2GSint}
\title{ Convertors for GeneSpring GSint and Bioconductor exprSet objects }

\description{
These functions convert GeneSpring Experiment (Interpretation) objects
into BioConductor expression objects and vice versa.
}

\usage{
expr.set <- GSint2BC(interpretation, what = "nor")
gs.int <- BC2GSint(exprSet)
}

\arguments{
  \item{interpretation}{ GeneSpring Expereiment Interpretation object }
  \item{what}{ For \code{GSload.intBC()} only. Indicates what data from the
   GeneSpring Experiment Interpretation should be used.
   Valid values for \code{what} can be \code{nor} and \code{raw}, representing
   Normalized or Raw expression values. The Control values cannot be used.}
  \item{exprSet}{ GeneSpring Expereiment Interpretation object }
}

\details{
The GeneSpring Experiment Interpretation and the BioConductor objects are
quite similar, but there are some differences. GeneSpring interpretations
can contain information on both normalized and original raw values, and
can include, Standard Error, Standard Deviation and number of replicates
information, but the BioConductor objects can contain more sample attribute
information in the form of the MIAME annotations.

These functions provide convertors for both types of objects.

When converting a GeneSpring object into a BioConductor object, the user
has the choice of either using the normalized or raw expression values for
the BioConductor exprSet object. Conversely, when a BioConductor objects is
converted into a GeneSpring object, the expression values are loaded as
normalized values.

The phenoData objects describing the phenotypical data for the samples in a
BioConductor object are converted into Experimental Parameter objects in the
GeneSpring class object, and vice versa.

The experiment name and any of the other annotations for the BioConductor
objects that are stored in the MIAME objects are currently not converted,
although future versions of these convertors may provide better mapping.
}

\value{
The return value depends on which fucntion was called.
The \code{BC2GSint()} function returns an object of class \code{GSint}.
The \code{GSint2BC()} function returns a BioConductor object of class \code{exprSet}.
See the documentation on \code{GSint} and \code{exprSet} for more information.
}

\references{ 

For more information on using GeneSpring with R see
\url{http://www.chem.agilent.com/scripts/generic.asp?lpage=34733}
}
\author{ 
   Thon de Boer, Agilent Technologies, Santa Clara, CA, USA \email{thon\_deboer@agilent.com}

}
\note{ This and any other functions in the GeneSpring package are only useful,
when using Agilent Technologies Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.exp}},
\code{\link{GSload.int}},
\code{\link{GSsave.exp}}
}
\examples{
#Use the example data etc. from exprSet
library(Biobase)
data(geneData)
data(geneCov)
covdesc<- list("Covariate 1", "Covariate 2", "Covariate 3")
names(covdesc) <- names(geneCov)
pdata <- new("phenoData", pData=geneCov, varLabels=covdesc)
eset <- new("exprSet", exprs=geneData, phenoData=pdata)

#Convert the objects into GeneSpring objects and back again
gs.int <- BC2GSint(eset)
expr.set <- GSint2BC(gs.int)

}
\keyword{ IO }% at least one, from doc/KEYWORDS
